@@ -35,7 +35,9 @@ enum MDButton {
 	MDB_Y		= 0x200,
 	MDB_Z		= 0x400,
 	MDB_M		= 0x800,
-	CMD_QUIT 	= 0x8000
+	CMD_QUIT 	= 0x8000,
+	CMD_QUICKLOAD = 0x8008,
+	CMD_QUICKSAVE = 0x800C
 };
 
 #endif
